.ajax-upload-preview-area {
    display: inline-block;
    background: #ddd;
    border-radius: 6px;
    border: 2px dashed #999;
    padding: 5px;
    margin-right: 5px;
    font-size: 12px;
    font-family: Arial, sans-serif;
    text-align:  center;
}
.ajax-upload-preview-area img {
    display: block;
    max-width: 130px;
    max-height: 130px;
    border: 1px solid #666;
    margin: 0 auto;
    margin-top: 5px;
}